@@ -1,15 +1,16 @@
-#!perl
 package Games::Word;
-require Exporter;
-@ISA = qw/Exporter/;
-@EXPORT_OK = qw/random_permutation is_permutation all_permutations
-                shared_letters shared_letters_by_position
-                random_string_from
-                is_substring all_substrings
-                is_subpermutation all_subpermutations/;
+our $VERSION = '0.05';
+
 
 use strict;
 use warnings;
+use base 'Exporter';
+our @EXPORT_OK = qw/random_permutation is_permutation all_permutations
+                    shared_letters shared_letters_by_position
+                    random_string_from
+                    is_substring all_substrings
+                    is_subpermutation all_subpermutations/;
+
 use Math::Combinatorics qw/factorial/;
 use Test::Deep::NoTest;
 
@@ -19,11 +20,7 @@ Games::Word - utility functions for writing word games
 
 =head1 VERSION
 
-Version 0.04 released 12/18/08
-
-=cut
-
-our $VERSION = '0.04';
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -300,12 +297,11 @@ L<http://search.cpan.org/dist/Games-Word>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008 Jesse Luehrs.
+Copyright 2008-2009 Jesse Luehrs.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
 
-1;
-
+1;
\ No newline at end of file
